PacketMessage

Struct PacketMessage 

pub struct PacketMessage {
    pub client: Entity,
    pub timestamp: Instant,
    pub id: i32,
    pub data: Bytes,
}

Fields

client: Entity

The client this packet originated from.

timestamp: Instant

The moment in time this packet arrived.

id: i32

This packet’s ID.

data: Bytes

The content of the packet, excluding the leading varint packet ID.

Implementations

Source

impl PacketMessage

pub fn decode<'a, P>(&'a self) -> Option<P>
where P: Packet + Decode<'a>,

Attempts to decode this packet as the packet P.

If the packet ID is mismatched or an error occurs, None is returned. Otherwise, Some is returned containing the decoded packet.